IAF
---

Integrate And Fire layer and variations thereof.

.. currentmodule:: sinabs.layers

.. autoclass:: IAF
    :members:

IAFRecurrent
-------------
.. autoclass:: IAFRecurrent
    :members:

IAFSqueeze
-------------
.. autoclass:: IAFSqueeze
    :members:
